@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw(Exporter);
 
-our $VERSION = '0.030';
+our $VERSION = '0.031';
 
 =head1 NAME
 
@@ -13,7 +13,7 @@ Tickit::DSL - domain-specific language for Tickit terminal apps
 
 =head1 VERSION
 
-version 0.030
+version 0.031
 
 =head1 SYNOPSIS
 
@@ -1173,9 +1173,10 @@ but eventually will be called when the current line is activated in the widget.
 =cut
 
 sub fileviewer(&;@) {
-	my $code = shift;
+	my ($code, $file) = splice @_, 0, 2;
 	my %args = (
-		file => @_
+		@_,
+		file => $file
 	);
 	my %parent_args = map {; $_ => delete $args{'parent:' . $_} } map /^parent:(.*)/ ? $1 : (), keys %args;
 
